# A modem implementation design for Home Assistant that supports caller ID and call rejection

Credit to Tim Vitz for his original work: https://github.com/vroomfonde1/basicmodem

Other source: https://github.com/havocsec/cx93001
